// The tool Scene Builder initially generates this class as a
// template of event handlers for components laid out as part
// of an initial version of a GUI. The user can manually update
// the event handler methods to enhance the GUI's behaviour.

// System
import javafx.application.Platform;
import javafx.fxml.FXML;

// Enumerations
import javafx.scene.input.KeyCode;
import javafx.scene.control.Alert.AlertType;
import javafx.scene.control.ButtonType;

// Controls
import javafx.scene.layout.GridPane;
import javafx.scene.control.Alert;
import javafx.scene.control.Button;
import javafx.scene.control.MenuItem;
import javafx.scene.control.TextArea;
import javafx.scene.control.PasswordField;
import javafx.scene.control.Label;
import javafx.scene.control.ProgressBar;
import javafx.scene.control.ProgressIndicator;
import javafx.scene.control.ColorPicker;
import javafx.scene.control.ComboBox;
import javafx.scene.paint.Color;
import javafx.scene.shape.Circle;

// Events
import javafx.event.ActionEvent;
import javafx.scene.input.KeyEvent;
import javafx.scene.input.MouseEvent;

public class Controller {
	
	// Injectable fields
	
    @FXML
    private Button Region00 = new Button();

    @FXML
    private Button Region01 = new Button();

    @FXML
    private Button Region02 = new Button();

    @FXML
    private Button Region10 = new Button();

    @FXML
    private Button Region11 = new Button();

    @FXML
    private Button Region12 = new Button();

    @FXML
    private MenuItem MenuClose = new MenuItem();

    @FXML
    private MenuItem MenuClear = new MenuItem();

    @FXML
    private MenuItem MenuAbout = new MenuItem();
    
    @FXML
    private GridPane myGridPane = new GridPane();

    @FXML
    private PasswordField myPasswordField = new PasswordField();
    
    @FXML
    private Label myLabel = new Label();

    @FXML
    private ProgressBar myProgressBar = new ProgressBar();

    @FXML
    private ProgressIndicator myProgressIndicator = new ProgressIndicator();
 
    @FXML
    private ColorPicker myColorPicker = new ColorPicker();

    @FXML
    private ComboBox<String> myComboBox = new ComboBox<String>();

    @FXML
    private TextArea myTextArea = new TextArea();
  
    @FXML
    private Circle myCircle00 = new Circle();  
  
    // Other attributes for implementing the GUI's control of events.
    
    float barProgress = 0F, indicatorProgress = 0F;
    String selectedAction = "";
	boolean region01Selected = false;
    boolean region11Selected = false;
    boolean region12Selected = false;
	Color defaultColor = Color.WHITE;
	
    // Injected Event Handlers
    
    @FXML
    void MenuCloseAction(ActionEvent event) {
    	if (event.getSource().equals(Region11))
    		return;
    	Platform.exit();
    }

    @FXML
    void MenuClearAction(ActionEvent event) {
    	barProgress = 0F;
    	indicatorProgress = 0F;
    	myProgressBar.toBack();
    	myProgressBar.setProgress(barProgress);
       	myProgressIndicator.toBack();
    	myProgressIndicator.setProgress(indicatorProgress);
    	myPasswordField.clear();
    	myLabel.setText("myLabel");
    	myTextArea.setText("");
		myCircle00.setVisible(false);
		myComboBox.setValue("");
		myColorPicker.setValue(defaultColor);
    }

    @FXML
    void MenuAboutAction(ActionEvent event) {
    	msgBox("Events GUI App\n\nVersion 0.1\nBuild id: 1234-5");
    }

    @FXML
    void Region00Action(ActionEvent event) {
		// Select Region00.
		if (event.getSource().equals(Region00)) {		
			if (!region01Selected && event.getSource().equals(Region00)) {
				region01Selected = true;
				myCircle00.setVisible(true);
			}
			else {
				region01Selected = false;
				myCircle00.setVisible(false);
			}
		}
		
		// Display password if Region00 is selected.
		if (region01Selected && event.getSource().equals(myPasswordField))
			msgBox("Password entered is: " + myPasswordField.getText());
    }

    @FXML
    void Region01Action(ActionEvent event) {
    	barProgress += 0.1F;
    	myProgressBar.setProgress(barProgress);
    }

    @FXML
    void Region02Action(ActionEvent event) {
    	indicatorProgress += 0.1F;
    	myProgressIndicator.setProgress(indicatorProgress);
    }

    @FXML
    void TextAreaKey(KeyEvent event) {
    	if (event.getCode() == KeyCode.ENTER) {
    		msgBox("<Enter> key pressed!");
    	}
    }

    @FXML
    void Region10Action(ActionEvent event) {
    	myLabel.setText(myTextArea.getText());
    }

    @FXML
    void Region11Action(ActionEvent event) {
    	if (!region11Selected) {
    		region11Selected = true;
        	msgBox("Region11 selected!");
    	}
        else {
        	region11Selected = false;
			msgBox("Region11 deselected!");
        }
    }

    @FXML
    void Region12Action(ActionEvent event) {
       	if (!region12Selected) {
    		region12Selected = true;
        	msgBox("Region12 selected!");
    	}
        else {
        	region12Selected = false;
			msgBox("Region12 deselected!");
        }
    }
 

    @FXML
    void myPasswordFieldKey(KeyEvent event) {
    	if (event.getCode() == KeyCode.ENTER) {
    		msgBox("Password entered!");
    	}
    }

 
    @FXML
    void myComboBoxAction(ActionEvent event) {
    	// This dummy entry required to handle the drop down of the ComboBox's choices.
		msgBox("Drop-down choice selected!");
    }

    @FXML
    void myColorPickerAction(ActionEvent event) {
		msgBox("Color choice selected!");
	}
	
    @FXML
    void initialize() {
    	
        assert Region00 != null : "fx:id=\"Region00\" was not injected: check your FXML file 'layout.fxml'.";
        assert Region01 != null : "fx:id=\"Region01\" was not injected: check your FXML file 'layout.fxml'.";
        assert Region02 != null : "fx:id=\"Region02\" was not injected: check your FXML file 'layout.fxml'.";
        assert Region10 != null : "fx:id=\"Region10\" was not injected: check your FXML file 'layout.fxml'.";
        assert Region11 != null : "fx:id=\"Region11\" was not injected: check your FXML file 'layout.fxml'.";
        assert Region12 != null : "fx:id=\"Region12\" was not injected: check your FXML file 'layout.fxml'.";
        assert myTextArea != null : "fx:id=\"myTextArea\" was not injected: check your FXML file 'layout.fxml'.";
        assert MenuClose != null : "fx:id=\"MenuClose\" was not injected: check your FXML file 'layout.fxml'.";
        assert MenuClear != null : "fx:id=\"MenuClear\" was not injected: check your FXML file 'layout.fxml'.";
        assert MenuAbout != null : "fx:id=\"MenuAbout\" was not injected: check your FXML file 'layout.fxml'.";
        assert myPasswordField != null : "fx:id=\"myPasswordField\" was not injected: check your FXML file 'layout.fxml'.";
        assert myProgressBar != null : "fx:id=\"myProgressBar\" was not injected: check your FXML file 'layout.fxml'.";
        assert myProgressIndicator != null : "fx:id=\"myProgressIndicator\" was not injected: check your FXML file 'layout.fxml'.";
        assert myColorPicker != null : "fx:id=\"myColorPicker\" was not injected: check your FXML file 'layout.fxml'.";
        assert myComboBox != null : "fx:id=\"myComboBox\" was not injected: check your FXML file 'layout.fxml'.";

        // Define handler for PasswordField's 'key pressed event
        
        // Add choice objects to ComboBox.
        myComboBox.getItems().addAll("Animate", "Clear");
        
        // Define handler for ComboBox's "choice selected" event.
        myComboBox.setOnAction(event -> {
        	if (region11Selected) {
	            selectedAction = myComboBox.getSelectionModel().getSelectedItem();
	            msgBox("'" + selectedAction + "' item selected in Combo box!");
	            myTextArea.setText(selectedAction);
        	}
        });
        
        // Define handler for ColorPicker's "color selected" event.
        myColorPicker.setOnAction(event -> {
        	if (region12Selected) {
                Color c = myColorPicker.getValue();
                myTextArea.setText("New Color's RGB --> R = " + c.getRed() +
								   ", G = " + c.getGreen() + ", B = " + c.getBlue());
        	}
        });
    }
        
// Auxiliary Methods
        
    void msgBox(String msg) {
    	Alert alert = new Alert(AlertType.INFORMATION);
		alert.setTitle("Message Window");
		alert.setHeaderText("INFORMATION MESSAGE");
		alert.setContentText(msg);
    		alert.showAndWait();
    }

} // end Controller
